#!/usr/bin/env node

import { Command } from 'commander';
import inquirer from 'inquirer';
import chalk from 'chalk';
import { setApiKey, getApiKey, deleteApiKey } from '../lib/config.js';
import { getUncommittedChanges, commitChanges } from '../lib/git.js';
import { generateCommitMessage } from '../lib/ai.js';

const program = new Command();

program
  .version('1.0.1')
  .description('A CLI tool for generating commit messages using AI');

// Command to configure AI providers
program
  .command('ai')
  .description('Configure AI provider settings')
  .option('--openai <key>', 'Set OpenAI API key')
  .option('--remove <provider>', 'Remove API key for specified provider')
  .action(async (options) => {
    try {
      if (options.openai) {
        setApiKey('openai', options.openai);
        console.log(chalk.green('OpenAI API key has been saved successfully!'));
      }
      
      if (options.remove) {
        deleteApiKey(options.remove);
        console.log(chalk.yellow(`API key for ${options.remove} has been removed.`));
      }
    } catch (error) {
      console.error(chalk.red('Error:'), error.message);
      process.exit(1);
    }
  });

// Command to generate commit message
program
  .command('generate')
  .description('Generate a commit message')
  .option('-y, --yes', 'Skip confirmation and commit directly')
  .action(async (options) => {
    try {
      // Check if OpenAI API key is configured
      if (!getApiKey('openai')) {
        console.error(chalk.red('Error: OpenAI API key not configured.'));
        console.log(chalk.yellow('Please run: cligitmessageai ai --openai YOUR_KEY'));
        process.exit(1);
      }

      // Get git changes
      const changes = await getUncommittedChanges();
      
      if (!changes.isRepo) {
        console.error(chalk.red('Error: Not a git repository'));
        process.exit(1);
      }

      if (![...changes.staged, ...changes.modified, ...changes.created, ...changes.deleted].length) {
        console.log(chalk.yellow('No changes detected to commit.'));
        process.exit(0);
      }

      console.log(chalk.blue('\nAnalyzing changes...'));
      const commitMessage = await generateCommitMessage(changes);

      if (!options.yes) {
        const { confirm, editMessage } = await inquirer.prompt([
          {
            type: 'confirm',
            name: 'confirm',
            message: `Generated commit message:\n${chalk.green(commitMessage)}\n\nWould you like to use this message?`,
            default: true
          },
          {
            type: 'input',
            name: 'editMessage',
            message: 'Enter your modified commit message:',
            default: commitMessage,
            when: (answers) => !answers.confirm
          }
        ]);

        const finalMessage = confirm ? commitMessage : editMessage;
        await commitChanges(finalMessage);
        console.log(chalk.green('\nChanges committed successfully!'));
      } else {
        await commitChanges(commitMessage);
        console.log(chalk.green('\nChanges committed successfully!'));
      }
    } catch (error) {
      console.error(chalk.red('Error:'), error.message);
      process.exit(1);
    }
  });

program.parse(process.argv); 